@@ -29,14 +29,19 @@ eval "$(${conda_dir}/Scripts/conda.exe 'shell.bash' 'hook')"
 # 2. Create test environment at ./env
 if [ ! -d "${env_dir}" ]; then
     printf "* Creating a test environment\n"
-    conda create ${CONDA_CHANNEL_FLAGS} --prefix "${env_dir}" -y python="$PYTHON_VERSION"
+    conda create --prefix "${env_dir}" -y python="$PYTHON_VERSION"
 fi
 conda activate "${env_dir}"
 
-# 3. Install Conda dependencies
+# 3. Install minimal build tools
+pip --quiet install cmake>=3.18.0 ninja
+
+# 4. Install Conda dependencies
 printf "* Installing dependencies (except PyTorch)\n"
 conda env update --file "${this_dir}/environment.yml" --prune
 
-# 4. Download
+# 5. Download
 printf "* Downloading SpaCy English models\n"
-python -m spacy download en
+python -m spacy download en_core_web_sm
+printf "* Downloading SpaCy German models\n"
+python -m spacy download de_core_news_sm
