@@ -1,9 +1,9 @@
 import time
 
 import torch
-from torchtext.experimental.datasets.raw import AG_NEWS
-from torchtext.experimental.transforms import basic_english_normalize
 from torchtext.data.utils import get_tokenizer
+from torchtext.datasets import AG_NEWS
+from torchtext.prototype.transforms import basic_english_normalize
 
 
 def benchmark_basic_english_normalize():
@@ -15,20 +15,20 @@ def benchmark_basic_english_normalize():
 
     existing_basic_english_tokenizer = get_tokenizer("basic_english")
     experimental_basic_english_normalize = basic_english_normalize()
-    experimental_jit_basic_english_normalize = torch.jit.script(experimental_basic_english_normalize.to_ivalue())
+    experimental_jit_basic_english_normalize = torch.jit.script(experimental_basic_english_normalize)
 
     # existing eager lookup
-    train, _ = AG_NEWS()
+    train = AG_NEWS(split="train")
     print("BasicEnglishNormalize - Eager Mode")
     _run_benchmark_lookup(train, existing_basic_english_tokenizer)
 
     # experimental eager lookup
-    train, _ = AG_NEWS()
+    train = AG_NEWS(split="train")
     print("BasicEnglishNormalize Experimental - Eager Mode")
     _run_benchmark_lookup(train, experimental_basic_english_normalize)
 
     # experimental jit lookup
-    train, _ = AG_NEWS()
+    train = AG_NEWS(split="train")
     print("BasicEnglishNormalize Experimental - Jit Mode")
     _run_benchmark_lookup(train, experimental_jit_basic_english_normalize)
 
