@@ -6,7 +6,7 @@ script_dir="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"
 
 export BUILD_TYPE="conda"
 export NO_CUDA_PACKAGE=1
-setup_env 0.8.0
+setup_env
 export SOURCE_ROOT_DIR="$PWD"
 setup_conda_pytorch_constraint
 setup_visual_studio_constraint
