@@ -1,18 +1,22 @@
+#include <torchtext/csrc/common.h>
+
 #include <fstream>
 #include <ios>
-#include <iostream>
 #include <limits>
-#include <string>
-#include <vector>
 
 namespace torchtext {
 namespace impl {
 
-int64_t divup(int64_t x, int64_t y) { return (x + y - 1) / y; }
+int64_t divup(int64_t x, int64_t y) {
+  return (x + y - 1) / y;
+}
 
-void infer_offsets(const std::string &file_path, int64_t num_lines,
-                   int64_t chunk_size, std::vector<size_t> &offsets,
-                   int64_t num_header_lines) {
+void infer_offsets(
+    const std::string& file_path,
+    int64_t num_lines,
+    int64_t chunk_size,
+    std::vector<size_t>& offsets,
+    int64_t num_header_lines) {
   std::ifstream fin;
   fin.open(file_path, std::ios::in);
 
